import Layout from '@/components/layout'
export default [
  {
    path: '/',
    name: 'Layout',
    component: Layout,
    redirect: '/calendar',
    hidden: true
  },
  {
    path: '/meeting-create',
    component: Layout,
    hidden: true,
    children: [
      {
        path: '',
        component: () => import('@/pages/meeting/index.vue'),
        name: 'MeetingCreate',
        meta: { title: '创建直播', permission: 'f_tencentmeeting_create' }
      }
    ]
  },
  {
    path: '/meeting-update',
    component: Layout,
    hidden: true,
    children: [
      {
        path: '',
        component: () => import('@/pages/meeting/index.vue'),
        name: 'MeetingUpdate',
        meta: { title: '更新直播', permission: 'f_tencentmeeting_update' }
      }
    ]
  },
  {
    path: '/meeting-account-create',
    component: Layout,
    hidden: true,
    children: [
      {
        path: '',
        component: () => import('@/pages/meeting/index.vue'),
        name: 'MeetingAccountCreate',
        meta: { title: '创建直播', permission: 'f_tencentmeeting_create' }
      }
    ]
  },
  {
    path: '/calendar',
    component: Layout,
    meta: { onlyShowOneChild: true, permission: 'menus_live_date_manage' },
    children: [
      {
        path: '',
        name: 'Calendar',
        component: () => import('@/pages/calendar/index'),
        meta: { title: '直播日历', icon: 'el-icon-user' }
      }
    ]
  },
  {
    path: '/system',
    component: Layout,
    redirect: '/system/role',
    name: 'System',
    meta: { title: '系统管理', icon: 'el-icon-setting', permission: 'menus_system_manage' },
    children: [
      {
        path: 'role',
        name: 'Role',
        component: () => import('@/pages/system/role/index'),
        meta: { title: '角色管理', icon: 'el-icon-s-check', permission: 'menus_roles' }
      },
      {
        path: 'roleToUser',
        name: 'RoleToUser',
        hidden: true,
        component: () => import('@/pages/system/role/role-to-user/index'),
        meta: { title: '管理角色用户', icon: '' }
      },
      {
        path: 'account',
        name: 'Account',
        component: () => import('@/pages/system/account/index'),
        meta: { title: '账号管理', icon: 'el-icon-key', permission: 'menus_users' }
      },
      {
        path: 'permission',
        name: 'Permission',
        component: () => import('@/pages/system/permission/index'),
        meta: { title: '权限管理', icon: 'el-icon-finished', permission: 'menus_permissions' }
      }
    ]
  },
  {
    path: '/tencent',
    component: Layout,
    redirect: '/tencent/account',
    name: 'Tencent',
    meta: { title: '腾讯会议管理', icon: 'el-icon-setting', permission: 'menus_tencent_meeting_manage' },
    children: [
      {
        path: 'account',
        name: 'TencentAccount',
        component: () => import('@/pages/tencent/account/index'),
        meta: { title: '账号管理', icon: 'el-icon-key', permission: 'menus_tencent_account' }
      }
    ]
  },
  {
    path: '/my',
    component: Layout,
    meta: { onlyShowOneChild: true, permission: 'menus_personal' },
    children: [
      {
        path: '',
        name: 'My',
        component: () => import('@/pages/my/index.vue'),
        meta: { title: '个人中心', icon: 'el-icon-user' }
      }
    ]
  },
  {
    path: '/search',
    component: Layout,
    hidden: true,
    children: [
      {
        path: '',
        name: 'Search',
        component: () => import('@/pages/search/index.vue'),
        meta: { title: '搜索' }
      }
    ]
  },
  {
    path: '/error-page',
    component: Layout,
    redirect: '/error-page/404',
    name: 'ErrorPage',
    meta: { title: '访问出错' },
    hidden: true,
    children: [
      {
        path: '404',
        name: '404',
        component: () => import('@/pages/error-page/404'),
        meta: { title: '404', icon: '' }
      },
      {
        path: '401',
        name: '401',
        component: () => import('@/pages/error-page/401'),
        meta: { title: '401', icon: '' }
      }
    ]
  },
  { path: '*', redirect: '/error-page', hidden: true }
]
