import store from '@/store'
import router from '@/router'
/**
 * Use meta.role to determine if the current user has permission
 * @param roles
 * @param routeRoles
 */
function hasPermission(roles, routeRoles) {
  if (Array.isArray(routeRoles)) {
    return roles.some(role => routeRoles.includes(role))
  } else {
    return true
  }
}
export default class BeforeEnter {
  constructor(opt) {
    this.opt = opt || {}
  }

  async update(to, from, next) {
    const isLogin = store.state.user.isLogin || (await store.dispatch('checkLogin'))
    if (!isLogin) {
      window.location.href = this.getLoginUrl()
      next()
    } else {
      const hasRoles = store.state.user.hasRoles || (await store.dispatch('checkRoles'))
      const perms = await store.dispatch('checkPermissions')
      console.log(perms)
      if (hasRoles) {
        if (to.path.includes('error-page')) {
          next()
        } else {
          const roles = store.state.user.roles.map(item => item.name)
          if (!hasPermission(roles, to.meta.roles)) {
            // next(loginUrl)
            router.push('/error-page/401')
          }
          next()
        }
      } else {
        window.location.href = this.getLoginUrl()
      }
    }
    next()
  }

  getLoginUrl() {
    const loginUrl = webConf.others.loginUrl
    let rdUrl = window.location.href
    if (rdUrl.includes('error-page')) {
      rdUrl = window.location.protocol + '//' + window.location.host
    }
    return `${loginUrl}?rd=${encodeURIComponent(rdUrl)}`
  }
}
